@@ -1,8 +1,10 @@
+from collections import namedtuple
 import argparse
 import sys
 import os
 
 from . import Job
+from .client import logger
 
 
 def run_job(args):
